@@ -1,15 +1,9 @@
 # -*- coding: utf-8 -*-
 
-# Hack for Python 2, linux-64 (maybe more?)
-# You can get a (probable) double free() deep in zeromq's TCP socket code:
-# *** Error in `/home/pwang/anaconda2-5/bin/python': free(): invalid pointer: 0x00007fe9b3fffb80 ***
-# ../../../../../libzmq.so.5.1.2(_ZN3zmq13tcp_address_t9to_stringERNSt7__cxx1112basic_stringIcSt11char_traitsIcESaIcEEE+0xb8)[0x7f29d2be46c8]
-# ../../../../../libzmq.so.5.1.2(_ZN3zmq14tcp_listener_t11set_addressEPKc+0x61)[0x7f29d2be82c1]
-# ../../../../../libzmq.so.5.1.2(_ZN3zmq13socket_base_t4bindEPKc+0x58e)[0x7f29d2bd533e]
-# Importing it very early seems to avoid this problem.
-# Other projects have run into similar issues:
-# https://github.com/pytorch/pytorch/issues/2507
-import zmq
+try:
+    import zmq
+except:
+    pass
 
 # Std imports
 import ctypes
@@ -22,7 +16,10 @@ import time
 
 # To prevent a race condition with ZMQ
 # See issue 5324
-import zmq
+try:
+    import zmq
+except:
+    pass
 
 # Load GL library to prevent segmentation faults on some Linux systems
 # See issues 3226 and 3332
